@@ -1,18 +1,20 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver;
+package Neo4j::Driver 1.01; # TRIAL
 # ABSTRACT: Neo4j community graph database driver for Bolt and HTTP
-$Neo4j::Driver::VERSION = '1.00'; # TRIAL
+
 
 use Carp qw(croak);
+use List::Util 1.33 qw(none);
 
 use URI 1.25;
 use Neo4j::Driver::Events;
 use Neo4j::Driver::Session;
 
+use Neo4j::Driver::Type::Bytes;
+use Neo4j::Driver::Type::DateTime;
+use Neo4j::Driver::Type::Duration;
 use Neo4j::Driver::Type::Node;
 use Neo4j::Driver::Type::Relationship;
 use Neo4j::Driver::Type::Path;
@@ -28,13 +30,13 @@ my %NEO4J_DEFAULT_PORT = (
 my %OPTIONS = (
 	auth => 'auth',
 	cypher_params => 'cypher_params_v2',
-	encrypted => 'tls',
 	concurrent_tx => 'concurrent_tx',
+	encrypted => 'encrypted',
 	max_transaction_retry_time => 'max_transaction_retry_time',
 	timeout => 'timeout',
-	tls => 'tls',
-	tls_ca => 'tls_ca',
-	trust_ca => 'tls_ca',
+	tls => 'encrypted',
+	tls_ca => 'trust_ca',
+	trust_ca => 'trust_ca',
 	uri => 'uri',
 );
 
@@ -53,7 +55,7 @@ sub new {
 	my ($class, $config, @extra) = @_;
 	
 	my $self = bless { config => { %DEFAULTS } }, $class;
-	$self->{plugins} = Neo4j::Driver::Events->new;
+	$self->{events} = Neo4j::Driver::Events->new;
 	
 	croak __PACKAGE__ . "->new() with multiple arguments unsupported" if @extra;
 	$config = { uri => $config } if ref $config ne 'HASH';
@@ -73,12 +75,10 @@ sub _check_uri {
 		$uri =~ s|^|neo4j:| if $uri =~ m{^//};
 		$uri = URI->new($uri);
 		
-		if ( ! $uri->scheme ) {
-			croak sprintf "Failed to parse URI '%s'", $uri;
-		}
-		if ( $uri->scheme !~ m/^https?$|^bolt$|^neo4j$/ ) {
-			croak sprintf "URI scheme '%s' unsupported; use 'bolt', 'http', or 'neo4j'", $uri->scheme // "";
-		}
+		$uri->scheme or croak
+			sprintf "Failed to parse URI '%s'", $uri;
+		$uri->scheme =~ m/^(?:https?|bolt|neo4j)$/i or croak
+			sprintf "URI scheme '%s' unsupported; use 'bolt', 'http', or 'neo4j'", $uri->scheme;
 		
 		if (my $userinfo = $uri->userinfo(undef)) {
 			my @userinfo = $userinfo =~ m/^([^:]*):?(.*)/;
@@ -105,7 +105,7 @@ sub _fix_neo4j_uri {
 	croak "The concurrent_tx config option may only be used with http:/https: URIs" if $self->{config}->{concurrent_tx};
 	
 	my $uri = $self->{config}->{uri};
-	$uri->scheme( exists $INC{'Neo4j/Bolt.pm'} ? 'bolt' : $self->{config}->{tls} ? 'https' : 'http' );
+	$uri->scheme( exists $INC{'Neo4j/Bolt.pm'} ? 'bolt' : $self->{config}->{encrypted} ? 'https' : 'http' );
 	$uri->port( $NEO4J_DEFAULT_PORT{ $uri->scheme } ) if ! $uri->_port;
 }
 
@@ -134,8 +134,8 @@ sub config {
 	if (@options < 2) {
 		# get config option
 		my $key = $options[0];
-		croak "Unsupported config option: $key" unless grep m/^$key$/, keys %OPTIONS;
-		return $self->{$OPTIONS{$key}} // $self->{config}->{$OPTIONS{$key}};
+		croak sprintf "Unsupported config option: %s", $key if none {$_ eq $key} keys %OPTIONS;
+		return $self->{config}->{$OPTIONS{$key}};
 	}
 	
 	croak "Unsupported sequence: call config() before session()" if $self->{server_info};
@@ -154,10 +154,6 @@ sub config {
 sub session {
 	my ($self, @options) = @_;
 	
-	if (! $self->{server_info}) {
-		warnings::warnif deprecated => sprintf "Internal API %s->{%s} may be unavailable in Neo4j::Driver 1.00", __PACKAGE__, $_ for grep { $self->{$_} } @OPTIONS{ sort keys %OPTIONS };
-	}
-	
 	@options = %{$options[0]} if @options == 1 && ref $options[0] eq 'HASH';
 	my %options = $self->_parse_options('session', ['database'], @options);
 	
@@ -171,18 +167,20 @@ sub session {
 sub _parse_options {
 	my (undef, $context, $supported, @options) = @_;
 	
-	croak "Odd number of elements in $context options hash" if @options & 1;
+	croak sprintf "Odd number of elements in %s options hash", $context if @options & 1;
 	my %options = @options;
 	
+	warnings::warnif deprecated => "Config option tls is deprecated; use encrypted" if $options{tls};
+	warnings::warnif deprecated => "Config option tls_ca is deprecated; use trust_ca" if $options{tls_ca};
+	
 	if ($options{cypher_params}) {
-		croak "Unimplemented cypher params filter '$options{cypher_params}'" if $options{cypher_params} !~ m<^\x02|v2$>;
+		$options{cypher_params} =~ m<^(?:\x02|v2)$> or croak
+			sprintf "Unimplemented cypher params filter '%s'", $options{cypher_params};
 	}
 	
-	my @unsupported = ();
-	foreach my $key (keys %options) {
-		push @unsupported, $key unless grep m/^$key$/, @$supported;
-	}
-	croak "Unsupported $context option: " . join ", ", sort @unsupported if @unsupported;
+	my @unsupported = grep { my $key = $_; none {$_ eq $key} @$supported } keys %options;
+	@unsupported and croak
+		sprintf "Unsupported %s option: %s", $context, join ", ", sort @unsupported;
 	
 	return %options;
 }
@@ -194,7 +192,7 @@ sub plugin {
 	
 	croak "plugin() with more than one argument is unsupported" if @extra;
 	croak "Unsupported sequence: call plugin() before session()" if $self->{server_info};
-	$self->{plugins}->_register_plugin($plugin);
+	$self->{events}->_register_plugin($plugin);
 	return $self;
 }
 
@@ -224,7 +222,7 @@ Neo4j::Driver - Neo4j community graph database driver for Bolt and HTTP
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -278,8 +276,8 @@ the recommended protocol. However, Perl support for it tends
 to lag behind after major updates to Neo4j.
 
 This driver supports Bolt, but doesn't bundle the necessary XS
-packages. You will need to install L<Neo4j::Bolt> separately
-to enable Bolt for this driver.
+packages. You will need to install S<L<Neo4j::Bolt> 0.4201> or
+later separately to enable Bolt for this driver.
 
 =item HTTP / HTTPS
 
@@ -301,6 +299,10 @@ install L<LWP::Protocol::https> separately to enable HTTPS.
 The protocol is automatically chosen based on the URI scheme.
 See L<Neo4j::Driver::Config/"uri"> for details.
 
+Version 1 of Neo4j::Driver is targeting Perl v5.20 and later.
+Patches will be accepted to address issues with Perl versions
+as old as v5.16.3 for as long as practical.
+
 =head1 METHODS
 
 L<Neo4j::Driver> implements the following methods.
@@ -395,18 +397,6 @@ Interacting with a Neo4j database:
 
 =back
 
-Official API documentation:
-
-=over
-
-=item * L<Neo4j Driver API Specification|https://github.com/neo4j/docs-bolt/blob/main/modules/ROOT/pages/driver-api/index.adoc>
-
-=item * L<Neo4j Drivers Manual|https://neo4j.com/docs/java-manual/5/>
-
-=item * L<Neo4j HTTP API Docs|https://neo4j.com/docs/http-api/5/>
-
-=back
-
 Other Perl modules for working with Neo4j:
 
 =over
