@@ -1,11 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Net::HTTP::LWP;
+package Neo4j::Driver::Net::HTTP::LWP 1.01; # TRIAL
 # ABSTRACT: HTTP network adapter for libwww-perl
-$Neo4j::Driver::Net::HTTP::LWP::VERSION = '1.00'; # TRIAL
+
 
 use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Net::HTTP);
@@ -51,7 +49,8 @@ sub new {
 		croak "HTTPS does not support unencrypted communication; use HTTP" if $unencrypted;
 		$agent->ssl_opts( verify_hostname => 1 );
 		if (defined( my $trust_ca = $driver->config('trust_ca') )) {
-			croak "trust_ca file '$trust_ca' can't be used: $!" if ! open(my $fh, '<', $trust_ca);
+			croak sprintf "trust_ca file '%s' can't be used: %s", $trust_ca, $!
+				unless open my $fh, '<', $trust_ca;
 			$agent->ssl_opts( SSL_ca_file => $trust_ca );
 		}
 	}
@@ -142,7 +141,7 @@ Neo4j::Driver::Net::HTTP::LWP - HTTP network adapter for libwww-perl
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -231,7 +230,7 @@ Meant to facilitate reuse.
 
 =head1 SEE ALSO
 
-L<Neo4j::Driver::Net>
+L<Neo4j::Driver::Plugin>
 
 =head1 AUTHOR
 
