@@ -1,10 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
 
-package Neo4j::Driver::Plugin;
+package Neo4j::Driver::Plugin 1.01; # TRIAL
 # ABSTRACT: Plug-in interface for Neo4j::Driver
-$Neo4j::Driver::Plugin::VERSION = '1.00'; # TRIAL
+
 
 1;
 
@@ -20,7 +19,7 @@ Neo4j::Driver::Plugin - Plug-in interface for Neo4j::Driver
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNPOSIS
 
@@ -308,7 +307,9 @@ of Cypher queries or custom object-graph mapping.
 The driver primarily uses HTTP network adapters by first calling
 the C<request()> method, which initiates a request on the network,
 and then calling other methods to obtain information about the
-response. See L<Neo4j::Driver::Net> for more information.
+response. See
+L<Neo4j::Driver::Net|https://github.com/johannessen/neo4j-driver-perl/blob/0.52/lib/Neo4j/Driver/Net.pod>
+for more information.
 
  $adapter->request('GET', '/', undef, 'application/json');
  $status  = $adapter->http_header->{status};
@@ -486,7 +487,7 @@ a Neo4j HTTP adapter module. It may only be implemented by
 network adapters that actually offer custom result handlers.
 Note that the result handler API is currently internal and
 expected to change, and this method will likely disappear
-entirely in future; see L</"RESULT HANDLER API"> below.
+entirely in future; see L</"Result handler API"> below.
 
 =item uri
 
