@@ -1,14 +1,11 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Record;
+package Neo4j::Driver::Record 1.01; # TRIAL
 # ABSTRACT: Container for Cypher result values
-$Neo4j::Driver::Record::VERSION = '1.00'; # TRIAL
+
 
 use Carp qw(croak);
-use JSON::MaybeXS 1.003003 qw(is_bool);
 
 use Neo4j::Driver::ResultSummary;
 
@@ -35,7 +32,9 @@ sub get {
 	my ($self, $field) = @_;
 	
 	if ( ! defined $field ) {
-		warnings::warnif ambiguous => "Ambiguous get() on " . __PACKAGE__ . " with multiple fields" if @{$self->{row}} > 1;
+		warnings::warnif ambiguous =>
+			sprintf "Ambiguous get() on %s with multiple fields", __PACKAGE__
+			if @{$self->{row}} > 1;
 		return $self->{row}->[0];
 	}
 	
@@ -45,12 +44,14 @@ sub get {
 	return $self->{row}->[$unambiguous_key] if defined $unambiguous_key;
 	
 	if ( _looks_like_int $field ) {
-		croak "Field $field not present in query result" if $field < 0 || $field >= @{$self->{row}};
+		croak sprintf "Field %i not present in query result", $field
+			unless $field >= 0 && $field < @{$self->{row}};
 		return $self->{row}->[$field];
 	}
 	
-	my $key = $self->{column_keys}->key($field);
-	croak "Field '$field' not present in query result" if ! defined $key;
+	my $key = $self->_field_index( $field );
+	croak sprintf "Field '%s' not present in query result", $field
+		unless defined $key;
 	return $self->{row}->[$key];
 }
 
@@ -60,14 +61,73 @@ sub data {
 	
 	my %data = ();
 	foreach my $key (keys %{ $self->{column_keys} }) {
-		$data{$key} = $self->{row}->[ $self->{column_keys}->key($key) ];
+		$data{$key} = $self->{row}->[ $self->_field_index( $key ) ];
 	}
 	return \%data;
 }
 
 
+# Return the index of the given column in the result record array
+sub _field_index {
+	my ($self, $name) = @_;
+	
+	my $cache = $self->{column_keys};
+	return $cache->{$name} if length $name && exists $cache->{$name};
+	return $cache->{''}->{$name} if exists $cache->{''};
+	return undef;
+}
+
+
+# Parse the field names (result column keys) provided by the server and
+# return them as a hash ref for fast index lookups
+sub _field_names_cache {
+	my ($result) = @_;
+	
+	croak 'Result missing columns' unless $result && $result->{columns};
+	my $columns = $result->{columns};
+	my $cache = {};
+	for my $index (0 .. $#$columns) {
+		my $name = $columns->[$index];
+		
+		# Create lookup cache for both index and field name to the index.
+		# Move ambiguous index/name pairs to the '' sub-hash.
+		
+		if ( exists $cache->{$name} ) {
+			delete $cache->{$name};
+			$cache->{''}->{$name} = $index;
+		}
+		else {
+			$cache->{$name} = $index;
+		}
+		
+		if ( exists $cache->{$index} ) {
+			$cache->{''}->{$index} = delete $cache->{$index};
+		}
+		else {
+			$cache->{$index} = $index;
+		}
+	}
+	
+	return $cache;
+}
+
+# The field names (column keys / ex ResultColumns) are stored in a hash ref.
+# For each field, there are entries with keys for the name and the column index
+# in the result record array. The value is always the column index.
+# For example, for `RETURN 1 AS foo`, it would look like this:
+#   $cache = { 'foo' => 0, '0' => 0 };
+
+# Exceptionally, index/name collisions can occur (see record-ambiguous.t).
+# The field names lookup cache is limited to cases where no ambiguity exists.
+# Any field name which would also be a valid index is moved to a sub-hash
+# stored in the entry '' (empty string). Neo4j doesn't allow zero-length
+# field names, so '' itself is never ambiguous.
+
+
 sub summary {
+	# uncoverable pod (see consume)
 	my ($self) = @_;
+	warnings::warnif deprecated => "summary() in Neo4j::Driver::Record is deprecated; use consume() in Neo4j::Driver::Result instead";
 	
 	$self->{_summary} //= Neo4j::Driver::ResultSummary->new;
 	return $self->{_summary}->_init;
@@ -88,7 +148,7 @@ Neo4j::Driver::Record - Container for Cypher result values
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -105,7 +165,7 @@ version 1.00
 =head1 DESCRIPTION
 
 Container for Cypher result values. Records are returned from Cypher
-statement execution, contained within a Result. A record is
+query execution, contained within a Result. A record is
 a form of ordered map and, as such, contained values can be accessed
 by either positional index or textual key.
 
@@ -147,12 +207,9 @@ Return the keys and values of this record as a hash reference.
 
 =item * L<Neo4j::Driver>
 
-=item * L<Neo4j::Driver::Types>
+=item * L<Neo4j::Driver::B<Result>>
 
-=item * Equivalent documentation for the official Neo4j drivers:
-L<Record (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/Record.html>,
-L<Record (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.26/class/lib6/record.js~Record.html>,
-L<IRecord (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.26/api/Neo4j.Driver.IRecord.html>
+=item * L<Neo4j::Driver::Types>
 
 =back
 
