@@ -1,18 +1,16 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Result::Jolt;
+package Neo4j::Driver::Result::Jolt 1.01; # TRIAL
 # ABSTRACT: Jolt result handler
-$Neo4j::Driver::Result::Jolt::VERSION = '1.00'; # TRIAL
+
 
 # This package is not part of the public Neo4j::Driver API.
 
 
 use parent 'Neo4j::Driver::Result';
 
-use Carp qw(carp croak);
+use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Net::HTTP Neo4j::Driver::Result);
 use JSON::MaybeXS 1.002004 ();
 
@@ -125,14 +123,14 @@ sub _gather_results {
 	
 	if (@results == 1) {
 		$self->{result} = $results[0];
-		$self->{statement} = $params->{statements}->[0];
+		$self->{query} = $params->{queries}->[0];
 		return $self->_as_fully_buffered;
 	}
 	
-	# If the number of Cypher statements run wasn't exactly one, provide a list
+	# If the number of Cypher queries run wasn't exactly one, provide a list
 	# of all results so that callers get a uniform interface for all of them.
 	@results = map { __PACKAGE__->_new_result($_, undef, $params) } @results;
-	$results[$_]->{statement} = $params->{statements}->[$_] for (0 .. $#results);
+	$results[$_]->{query} = $params->{queries}->[$_] for (0 .. $#results);
 	$self->{attached} = 0;
 	$self->{exhausted} = 1;
 	$self->{result_list} = \@results if @results;
@@ -298,11 +296,9 @@ sub _deep_bless {
 			return bless $data, $cypher_types->{temporal};
 		}
 		if ($value =~ m/^-?P/) {
-			require Neo4j::Driver::Type::Duration;
 			bless $data, 'Neo4j::Driver::Type::Duration';
 		}
 		else {
-			require Neo4j::Driver::Type::DateTime;
 			bless $data, 'Neo4j::Driver::Type::DateTime';
 		}
 		return $data;
@@ -310,7 +306,6 @@ sub _deep_bless {
 	if ($sigil eq '#') {  # Bytes
 		$value =~ tr/ //d;  # spaces were allowed in the Jolt draft, but aren't actually implemented in Neo4j 4.2's jolt.JoltModule
 		$value = pack 'H*', $value;  # see neo4j#12660
-		require Neo4j::Driver::Type::Bytes;
 		return bless \$value, 'Neo4j::Driver::Type::Bytes';
 	}
 	
