@@ -1,11 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::SummaryCounters;
-# ABSTRACT: Statement statistics
-$Neo4j::Driver::SummaryCounters::VERSION = '1.00'; # TRIAL
+package Neo4j::Driver::SummaryCounters 1.01; # TRIAL
+# ABSTRACT: Query statistics
+
 
 sub new {
 	my ($class, $stats) = @_;
@@ -61,11 +59,11 @@ __END__
 
 =head1 NAME
 
-Neo4j::Driver::SummaryCounters - Statement statistics
+Neo4j::Driver::SummaryCounters - Query statistics
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 SYNOPSIS
 
@@ -83,7 +81,7 @@ version 1.00
 
 =head1 DESCRIPTION
 
-Contains counters for various operations that a statement triggered.
+Contains counters for various operations that a query triggered.
 
 To obtain summary counters, call
 L<Neo4j::Driver::ResultSummary/"counters">.
@@ -116,8 +114,7 @@ attributes.
 
 =item * L<Neo4j::Driver>
 
-=item * Equivalent documentation for the official Neo4j drivers:
-L<SummaryCounters (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/summary/SummaryCounters.html>
+=item * L<Neo4j::Driver::B<ResultSummary>>
 
 =back
 
