@@ -1,11 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Type::Node;
+package Neo4j::Driver::Type::Node 1.01; # TRIAL
 # ABSTRACT: Describes a node from a Neo4j graph
-$Neo4j::Driver::Type::Node::VERSION = '1.00'; # TRIAL
+
 
 # For documentation, see Neo4j::Driver::Types.
 
@@ -74,11 +72,4 @@ sub _hash {
 }
 
 
-# As long as we remain compatible with Neo4j::Types 1.00,
-# we need to register the warning category explicitly.
-package # private
-        Neo4j::Types;
-use warnings::register;
-
-
 1;
