@@ -1,11 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Type::Path;
+package Neo4j::Driver::Type::Path 1.01; # TRIAL
 # ABSTRACT: Directed sequence of relationships between two nodes
-$Neo4j::Driver::Type::Path::VERSION = '1.00'; # TRIAL
+
 
 # For documentation, see Neo4j::Driver::Types.
 
