@@ -1,11 +1,9 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Type::Point;
+package Neo4j::Driver::Type::Point 1.01; # TRIAL
 # ABSTRACT: Represents a Neo4j spatial point value
-$Neo4j::Driver::Type::Point::VERSION = '1.00'; # TRIAL
+
 
 # For documentation, see Neo4j::Driver::Types.
 
